@@ -19,20 +19,20 @@
 #' @param is_id \code{logical}: Is the query a unique identifier? Defaults to 
 #' \code{FALSE}, meaning that queries are assumed to be taxonomic names.
 #' @param children \code{logical}: Return child concepts for the provided
-#' query? DEPRECATED: use \code{\link{search_taxonomy}} instead.
+#' query? DEPRECATED: use \code{\link{ala_taxonomy}} instead.
 #' @param counts \code{logical}: return occurrence counts for all
 #' taxa found? \code{FALSE} by default. 
 #' DEPRECATED: use \code{\link{ala_counts}} instead.
 #' @param all_ranks \code{logical}: Include all available
 #' intermediate ranks for taxa? e.g. suborder, superfamily. Retrieving this
 #' information requires an additional web service call so will slow down the
-#' query. DEPRECATED: use \code{\link{search_taxonomy}} instead.
+#' query. DEPRECATED: use \code{\link{ala_taxonomy}} instead.
 #' @return An object of class \code{data.frame} and \code{ala_id}
 #' containing taxonomic information.
 #' @seealso \code{\link{select_columns}}, \code{\link{select_filters}} and
 #' \code{\link{select_locations}} for other ways to restrict the information returned
 #' by \code{\link{ala_occurrences}} and related functions.
-#' \code{\link{search_taxonomy}} to look up taxonomic trees.
+#' \code{\link{ala_taxonomy}} to look up taxonomic trees.
 #' @examples
 #' \dontrun{
 #' # Search using a single term
@@ -53,7 +53,7 @@ select_taxa <- function(query, is_id = FALSE, children = FALSE, counts = FALSE,
   if(missing(is_id)){is_id <- FALSE}
   if (!missing(children)) {
     warning("The `children` argument is now deprecated. To get information about
-  child taxonomic concepts, use `search_taxonomy` with the `downto` argument.
+  child taxonomic concepts, use `ala_taxonomy` with the `downto` argument.
   For more information about taxonomic searches, see vignette('taxonomic_information')")
   }
   if (!missing(counts)) {
@@ -63,7 +63,7 @@ select_taxa <- function(query, is_id = FALSE, children = FALSE, counts = FALSE,
   }
   if (!missing(all_ranks)) {
     warning("The `all_ranks` argument is now deprecated. All rank information is
-  provided by default in `search_taxonomy`.
+  provided by default in `ala_taxonomy`.
   For more information about taxonomic searches, see vignette('taxonomic_information')")
   }
   verbose <- getOption("galah_config")$verbose
@@ -77,14 +77,6 @@ select_taxa <- function(query, is_id = FALSE, children = FALSE, counts = FALSE,
   if (missing(query)) {
     stop("`select_taxa` requires a query to search for")
   }
-
-  # query_type <- deduce_query_type(query)
-  # 
-  # if (verbose) {
-  #   print_qt <- ifelse(query_type == "id", "identifiers",
-  #                      "scientific or common names")
-  #   message("Assuming that query term(s) provided are ", print_qt)
-  # }
   
   if (is_id) {
     matches <- id_query(query)   
@@ -196,34 +188,6 @@ identifier_lookup <- function(identifier) {
   result[names(result) %in% wanted_columns("taxa")]
 }
 
-# deduce_query_type <- function(query) {
-#   if (is.data.frame(query)) {
-#     return("name")
-#   }
-#   # Possible query types are 'id' and 'name'
-#   if (
-#     # APNI
-#     any(str_detect(query, "https://id.biodiversity.org.au")) ||
-#     # AFD
-#     any(str_detect(query, "afd.taxon:")) ||
-#     # NZOE
-#     any(str_detect(query, "NZOR")) ||
-#     # Index Fungorum
-#     any(str_detect(query, "urn:lsid:indexfungorum")) ||
-#     # Catalogue of life
-#     any(str_detect(query, "CoL:")) ||
-#     # CAAB
-#     !is.na(suppressWarnings(any(as.integer(query)))) ||
-#     # Aus Fungi and CoL - check if any digits in string- possibly this check
-#     # would cover all id types
-#     any(grepl("\\d", query)) ||
-#     # ALA special case
-#     any(str_detect(query, "ALA_"))) {
-#     return("id")
-#   }
-#   # By default assume 'name' type
-#   return("name")
-# }
 
 # make sure rank provided is in accepted list
 validate_rank <- function(df) {
